@@ -26,8 +26,10 @@ import platform
 import psutil
 import shutil
 from shutil import which
-from wrfplot import __version__
+from wrfplot._version import __version__
 from wrfplot.utils import quote
+import glob
+import subprocess
 
 # Define variables that would be used at later stage
 version = __version__
@@ -56,6 +58,7 @@ if platform.system() == "Windows":
     geos_trgt_dir = os.path.join("shapely", "DLLs", "\\")
     compiler = "--mingw64"
     nutika_exe_name = 'wrfplot.exe'  # os.path.join(output_dir, 'wrfplot.dist', 'wrfplot.exe')
+    frozen_version_file = os.path.join(project_root, "build", "windows", "wrfplot", "_version.py")
 
 elif platform.system() == "Linux":
     output_dir = os.path.join(project_root, 'build', 'linux')
@@ -66,6 +69,7 @@ elif platform.system() == "Linux":
     geos_trgt_dir = "shapely/.libs/"
     compiler = ""
     nutika_exe_name =  'wrfplot' #os.path.join(output_dir, 'wrfplot.dist', 'wrfplot')
+    frozen_version_file = os.path.join(project_root, "build", "linux", "wrfplot", "_version.py")
 
 # Tested on Miniconda Python 3.10.4
 # This is the place one need to be carefull. For wrfplot project, netcdf, shapely and pyproj modules were not detected
@@ -217,6 +221,7 @@ def create_makeself():
     if os.path.exists(os.path.join(output_dir, "wrfplot")):
         print("Creating Linux installer...")
         shutil.copy("installer.sh", output_dir)
+        os.system("chmod +x " + os.path.join(output_dir, "installer.sh"))
         print("Executing makeself command to create archive...")
         execute_cmd(makeself + " " + os.path.join(output_dir) + " " + os.path.join(output_dir, "wrfplot-linux-64bit.run") + " wrfplot_Linux_Installer " + "./installer.sh")
         if os.path.exists(os.path.join(output_dir, "wrfplot.run")):
@@ -348,9 +353,44 @@ def main():
             execute_cmd("pyinstaller --noconfirm --distpath " + output_dir + " wrfplot.spec")
 
         # test_wrfplt_exe()
+        update_verion()
         create_makeself()
 
 
+def clean_dirs():
+    if os.path.isdir('wrfplot.egg-info'):
+        shutil.rmtree('wrfplot.egg-info')
+    if os.path.exists(os.path.join(project_root, 'build')) and len(os.listdir(os.path.join(project_root, 'build'))) > 0:
+        files = glob.glob(os.path.join(project_root, 'build', '*'))
+        for f in files:
+            if os.path.isdir(f):
+                print("Removing directory", quote(f))
+                shutil.rmtree(f)
+            elif os.path.isfile(f):
+                print("Removing file", quote(f))
+                os.remove(f)
+
+def build_sdist():
+    if os.system("python -m build --sdist") == 0:
+        print("Successfully built source distribution package under 'build directory'...")
+        return True
+    else:
+        sys.exit("Failure to build source distribution package.\n Please correct the issue and build the executable again.")
+
+def update_verion():
+    if which("setuptools-git-versioning"):
+        VERSION = subprocess.check_output(["setuptools-git-versioning"]).strip().decode("utf-8").replace("v", "")
+    else:
+        VERSION = subprocess.check_output(["git", "describe", "--tags"]).strip().decode("utf-8").replace("v", "")
+    
+    print("Updating varion information to file with :", VERSION)
+    print("Version information will be updated in : " + frozen_version_file)
+    with open(frozen_version_file, "w") as _file:
+        _file.write("# Generated by wrfplot build file. Do not edit it manually...\n")
+        _file.write("__version__ = version = " + quote(VERSION))
+        _file.write('\n')
+
+   
 # Read script starts from here when this file is executed
 if __name__ == "__main__":
     # Decide wheather to build using nuitka or pyinstaller
@@ -358,6 +398,9 @@ if __name__ == "__main__":
         compile_module = "pyinstaller"
     # Check if we are running the script in correct filesystem
     check_fs()
+    clean_dirs()
+    build_sdist()
+    # sys.exit()
     startTime = time.time()
     main()
     total_time = time.time() - startTime
